@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 use 5.006;
 use strict;
 use warnings;
@@ -58,6 +58,8 @@ sub run {
 		%args
 	);
 
+	$j->headers = {};
+
 	$j->_build_terse();
 	
 	$j->request = $j->{_request_class}->new($args{plack_env});
@@ -202,7 +204,7 @@ sub raiseError {
 	} else {
 		push @{$self->{errors}}, $message;
 	}
-	$self->{status_code} = $code if ($code);
+	$self->{status_code} = $code if ($code && !$self->{status_code});
 	return $self;
 }
 
@@ -408,7 +410,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
