@@ -12,10 +12,10 @@ sub start {
 	my $path = $pkg->_path($pkg, $args{lib});
 	my $self = $pkg->new(
 		app => 1,
-		models => $pkg->_build_models($pkg, $path, $args{lib}),
-		views => $pkg->_build_views($pkg, $path, $args{lib}),
-		controllers => $pkg->_build_controllers($pkg, $path, $args{lib}),
-		plugins => $pkg->_build_plugins($pkg, $path, $args{lib}),
+		models => $pkg->_build_models($pkg, $path, $args{lib}, delete $args{models}),
+		views => $pkg->_build_views($pkg, $path, $args{lib}, delete $args{views}),
+		controllers => $pkg->_build_controllers($pkg, $path, $args{lib}, delete $args{controllers}),
+		plugins => $pkg->_build_plugins($pkg, $path, $args{lib}, delete $args{plugins}),
 		%args
 	);
 	$self->build_app() if ($self->can('build_app'));
@@ -28,7 +28,7 @@ sub preprocess_req {
 		(my $path = $t->request->uri->path) =~ s/\/$//;
 		if ($self->controllers->{_alias}) {
 			for my $candidate (keys %{$self->controllers->{_alias}}) {
-                        	my @captured = $path =~ m/$candidate/;
+                        	my @captured = $path =~ m/^$candidate$/;
                         	if (scalar @captured) {
                                 	$t->captured = \@captured;
                                 	$t->params->req = $req = $self->controllers->{_alias}->{$candidate}->{req};
@@ -42,42 +42,46 @@ sub preprocess_req {
 }
 
 sub _build_models {
-	my ($self, $pkg, $path, $lib) =@_; 
+	my ($self, $pkg, $path, $lib, $config) =@_; 
 	return $self->_load_modules(
 		path => $path,
 		pkg => $pkg,
 		type => 'Model',
-		lib => $lib
+		lib => $lib,
+		config => $config
 	);
 }
 
 sub _build_views {
-	my ($self, $pkg, $path, $lib) =@_; 
+	my ($self, $pkg, $path, $lib, $config) =@_; 
 	return $self->_load_modules(
 		path => $path,
 		pkg => $pkg,
 		type => 'View',
-		lib => $lib
+		lib => $lib,
+		config => $config
 	);
 }
 
 sub _build_controllers {
-	my ($self, $pkg, $path, $lib) =@_; 
+	my ($self, $pkg, $path, $lib, $config) =@_; 
 	return $self->_load_modules(
 		path => $path,
 		pkg => $pkg,
 		type => 'Controller',
-		lib => $lib
+		lib => $lib,
+		config => $config
 	);
 }
 
 sub _build_plugins {
-	my ($self, $pkg, $path, $lib) =@_; 
+	my ($self, $pkg, $path, $lib, $config) = @_; 
 	return $self->_load_modules(
 		path => $path,
 		pkg => $pkg,
 		type => 'Plugin',
-		lib => $lib
+		lib => $lib,
+		config => $config
 	);
 }
 
@@ -89,7 +93,8 @@ sub _load_modules {
 		(my $m = $l) =~ s/\//::/g;
 		[
 			"$args{path}/${type}/${l}.pm",
-			"$args{pkg}::${type}::${m}"
+			"$args{pkg}::${type}::${m}",
+			$args{config}{$m}
 		]
 	} $self->_recurse_directory("$args{path}/$type");
 	my %mods = ();
@@ -97,7 +102,7 @@ sub _load_modules {
 		require_module($module->[1]);
 	}
 	for my $module (@modules) {
-		$module = $module->[1]->new(app => 1);
+		$module = $module->[1]->new(app => 1, app_config => $module->[2]);
 		die $@ && next if $@;
 		$mods{_alias} = { %{$mods{_alias} || {}}, %{$Terse::Controller::dispatcher{ref $module}{_alias} || {}} }; 
 		$mods{_alias}{$module->capture} = { namespace => $module->namespace } if $module->{capture};
@@ -152,16 +157,14 @@ sub dispatch {
 	if (!$path && !$req) {
 		$req = lc(ref $self);
 	}
-
 	if ($self->controllers->{_alias}) {
 		for my $candidate (keys %{$self->controllers->{_alias}}) {
-			my @captured = $path =~ m/$candidate/;
+			my @captured = $path =~ m/^$candidate$/;
 			if (scalar @captured) {
                                 $path = $self->controllers->{_alias}->{$candidate}->{namespace};
 			}
 		}
 	}
-
 	my $controller = $t->controller($path);
 	if ($path && ! $controller) {
 		$t->logError('Path not found - ' . $path, 500);
@@ -177,7 +180,7 @@ sub dispatch {
 			$t->logError('Missing captured arguments', 500);
 			return;
 		}
-		if ($controller->default_req && !$t->params->req) {
+		if ($controller->default_req && !$controller->can($req)) {
 			$req = $controller->default_req;
 		}
 		return $controller->dispatch($req, $t, @params);
@@ -196,7 +199,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
