@@ -20,7 +20,7 @@ sub new {
 	$namespace =~ s/\:\:/\//g;
 	$self->namespace = lc( $namespace );
 	$self->default_req = [split "/", $self->namespace]->[-1];
-	$self->build_controller() if ($self->can('build_controller'));
+	$self->build_controller($self->app_config) if ($self->can('build_controller'));
 	return $self;
 }
 
@@ -30,7 +30,7 @@ sub preprocess_req {
 		my $alias = $Terse::Controller::dispatcher{ref $self}{_alias};
 		my $path = $t->request->uri->path;
 		for my $candidate (keys %{$alias}) {
-			my @captured = $path =~ m/$candidate/;
+			my @captured = $path =~ m/^$candidate$/;
 			if (scalar @captured) {
 				$t->captured = \@captured;
 				$req = $alias->{$candidate}->{req};
@@ -57,7 +57,7 @@ sub build_terse {
 			return $self->controllers->{$self->controllers->{_alias}->{$controller}->{namespace}}
 				if $self->controllers->{_alias}->{$controller};
 			for my $key (keys %{$self->controllers->{_alias}}) {
-				my @captured = $controller =~ m/$key/;
+				my @captured = $controller =~ m/^$key$/;
 				if (scalar @captured) {
 					$controller = $self->controllers->{$self->controllers->{_alias}->{$key}->{namespace}};
 					$t->captured = \@captured;
@@ -233,6 +233,8 @@ sub dispatch {
 		$t->logError('No callback found to dispatch the request', 400);
 		return;
 	}
+	$t->response_namespace = $self->namespace;
+	$t->response_handler = $callback if $callback !~ m/auth/;
 	$t->response_view = $dispatch->{view} if $dispatch->{view};
 	$t->content_type($dispatch->{content_type}) if $dispatch->{content_type};
 	if ($dispatch->{delayed}) {
@@ -276,7 +278,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
