@@ -8,7 +8,7 @@ sub new {
 	(my $namespace = $pkg) =~ s/^.*Model:://;
 	$namespace =~ s/\:\:/\//g;
 	$self->namespace = lc( $namespace );
-	$self->build_model() if ($self->can('build_model'));
+	$self->build_model($self->app_config) if ($self->can('build_model'));
 	return $self;
 }
 
@@ -25,7 +25,7 @@ Terse::Controller - models made simple.
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
