@@ -7,7 +7,7 @@ sub new {
 	my $self = $pkg->SUPER::new(@args);
 	my ($namespace) = $pkg =~ m/([^:]+)$/;
 	$self->namespace = lc( $namespace );
-	$self->build_plugin() if ($self->can('build_plugin'));
+	$self->build_plugin($self->app_config) if ($self->can('build_plugin'));
 	return $self;
 }
 
@@ -23,7 +23,7 @@ Terse::Plugin - plugins made simple.
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
