@@ -7,7 +7,7 @@ sub new {
 	my $self = $pkg->SUPER::new(@args);
 	my ($namespace) = $pkg =~ m/([^:]+)$/;
 	$self->namespace = lc( $namespace );
-	$self->build_view() if ($self->can('build_view'));
+	$self->build_view($self->app_config) if ($self->can('build_view'));
 	return $self;
 }
 
@@ -24,7 +24,7 @@ Terse::View - views made simple.
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
