@@ -12,7 +12,7 @@ sub new {
 		return 'Invalid environment no _sock or _stream_check in env';
 	}
 	$self->options = {
-		secret => 'ABABCABC-ABC-ABC-ABCD-ABCABCABCABC',
+		secret => $t->{_app_secret} || 'ABABCABC-ABC-ABC-ABCD-ABCABCABCABC',
 		upgrade    => $env->{HTTP_UPGRADE},
 		connection => $env->{HTTP_CONNECTION},
 		host       => $env->{HTTP_HOST},
@@ -202,7 +202,7 @@ Terse::WebSocket - Lightweight WebSockets
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
